%wa_initialize - Initializes communcication to WA-1500 wavemeter
%
% [wa1500, ret] = wa_initialize() opens the serial port on COM1 and sets
% the wavementer for obtaining single wavelength measurements in
% nanometers.
%
% The configuration chosen is: 
%
%   Display:    'Wavelength'
%   Medium:     'Air'
%   Resolution: 'Fixed'
%   Averaging:  'Off'
%   Units:      'nm'  
%
% EXAMPLE
% 
% First set up the wavemeter communiation: 
%   >> [wa1500, ret] = wa_initialize();
%
% Then read the wavelength:
%   >> wavelength = wa_readWavelength()
%
% See Also: wa1500, commandWave, wa_readWavelength
%

% 
%
% 7.10.2012
% pasqual@uw.edu
%
% Todd Karin
% 11/18/2013

function [wa1500, ret] = wa_initialize()

% remove all serial instruments from memory to clear any
% open resources conflicts
delete(instrfind) 
ret = 1;
% build matlab instrument to serial port COM1
% then open channel, put wavemeter into query mode so it doesn't 
% continue to fill buffer (single reading mode)
% then flush buffer and take a live measurement
try
wa1500 = serial('COM1', ...
    'Term', 'CR/LF', ...
    'tag','wa1500');

query = '@Q';
fopen(wa1500);
fprintf(wa1500, query);
flushinput(wa1500);

set(wa1500,'Timeout',1);

info = wa_getReading(wa1500);

% Catch if the wavemeter is unresponsive or no communication received.
if isempty(info{1})==1 | info{1}=='0'
    success = 0;
else
    success = 1;
end

if success
    % compare statusHex to verify the wavemeter is measuring in 'air' mode
    if bitand(hex2dec(info{2}), 256) ~= 256
        pause(.1);
        fprintf(wa1500, '@)');
        pause(.1);
        info = wa_getReading(wa1500);
        pause(.1);
    end

    % compare statusHex to verify the wavemeter is reporting 'nm' units
    if bitand(hex2dec(info{2}), 18) == 18
        info{2};
        fprintf(wa1500, '@''')
        pause(.1);    
        fprintf(wa1500, '@''')
        pause(.1);
        info = wa_getReading(wa1500);
    end

    if bitand(hex2dec(info{2}), 36) == 36
        pause(.1)
        fprintf(wa1500, '@''')
        pause(.1);
        info = wa_getReading(wa1500)
    end

    % compare statusHex to verify the wavemeter is in 'wavelength' mode
    if bitand(hex2dec(info{2}), 64) ~= 64
        fprintf(wa1500, '@(');
        pause(.1);
        info = wa_getReading(wa1500);
        pause(.1);
    end

    % compare statusHex to verify the wavemeter is in 'fixed' resolution mode
    if bitand(hex2dec(info{2}), 1024) ~= 1024
        fprintf(wa1500, '@*');
        pause(.1);
        info = wa_getReading(wa1500);
        pause(.1);
    end
    % compare statusHex to verify the wavemeter is not in 'averaging' mode
    % make next line:
    % if bitand(hex2dec(info{2}), 4096) ~= 4096 For averaging mode.
    if bitand(hex2dec(info{2}), 4096)== 4096
        fprintf(wa1500, '@+');
        pause(.1);
        info = wa_getReading(wa1500);
        pause(.1);
    end
    
    ret = 0;
end

catch err
    disp(err.message)
    ret = 1;
end
        
