%wa_readWavelength - Get a single wavelength measurement
% 
% wavelength = wa_readWavelength() gets a single wavelength reading from
% the wavemeter. Wavelength is returned in nm. Function returns 0 if there
% is an error reading the wavemeter.
%
% If speed is important, for slightly faster operation, initialize the
% instrument using
%
%   >> wa1500 = wa_findInstrument()
%
% Then read the wavelength using
%
%   >> wavelength = wa_readWavelength(wa1500)
%
%
% OUTPUT
%   Function returns a (double) wavelength reading if successful, and
%   returns 0 if there is an error.
%
%
% See also: wa1500, wa_initialize
%
%
%
% Todd Karin
% 11/18/2013
function [wavelength] = wa_readWavelength(varargin)

% Depending on input, either find the instrument or use the one given.
switch nargin
    case 0
        wa1500 = wa_findInstrument();
    case 1
        wa1500 = varargin{1};
end

% Get Reading
try
    % Do it twice to prevent errors.
    for j=1:2
        fprintf(wa1500, '@Q');
        response = fscanf(wa1500);
    end
    info = textscan(response, '%11c %4c %4c', 'delimiter', ',');
    
    % catch wavemeter thrown errors and return 0 if error found
    if strncmp(info{1},'~', 1) | strfind(info{1},'SIG')>0
        wavelength = 0;
    else 
        wavelength = str2double(info{1});
    end

    % Catch errors.
catch err
    disp('wavemeter read error')
    disp(err.message)
    info = {'0','0','0'};
    wavelength = 0;
end


